from setuptools import setup

setup(
    name='Gicanu-first-hello',
    version='0.1.0',
    author='Georgian Ivan',
    author_email='georgian.ivan95@gmail.com',
    packages=['my_own_package'],
    package_dir={'': 'src\\'},
    include_package_data=True

)